@@ -1,8 +1,9 @@
 from django.contrib import admin
 
-from .models import Post, Tag, TagSuggestion, Comment, Vote, Rating, Save, Flag, PostFlag, Ban
+from .models import Post, Tag, TagSuggestion, Comment, Vote, Rating, Save, Flag, PostFlag, Ban, Topic
 
 admin.site.register(Post)
+admin.site.register(Topic)
 admin.site.register(Tag)
 admin.site.register(TagSuggestion)
 admin.site.register(Comment)
